@@ -8,13 +8,14 @@ from abc import abstractmethod
 from collections.abc import Callable, Coroutine, Iterable, ValuesView
 from contextlib import suppress
 from datetime import datetime
+from functools import partial
 from itertools import chain
 from typing import Any, ParamSpec, TypeVar
 
 from aiohttp import ClientError, ClientResponseError, ClientSession
 
 from .._compat import cached_property
-from ..activity import ActivityTypes
+from ..activity import Activity, ActivityTypes, Source
 from ..backports.tasks import create_eager_task
 from ..const import Brand
 from ..doorbell import ContentTokenExpired, Doorbell, DoorbellDetail
@@ -81,6 +82,8 @@ class YaleXSData(SubscriberMixin):
         self._initial_sync_task: asyncio.Task | None = None
         self._error_exception_class = error_exception_class
         self._shutdown: bool = False
+        # Track last known state from WebSocket messages to avoid unnecessary updates
+        self._last_push_state: dict[str, dict[str, str]] = {}
 
     @cached_property
     def brand(self) -> Brand:
@@ -127,15 +130,19 @@ class YaleXSData(SubscriberMixin):
         push: AugustPubNub | SocketIORunner
         if self.brand is Brand.YALE_GLOBAL:
             push = SocketIORunner(self._gateway)
+            push_source = Source.WEBSOCKET
         else:
             push = AugustPubNub()
+            push_source = Source.PUBNUB
             for device in self._device_detail_by_id.values():
                 push.register_device(device)
         self.activity_stream = ActivityStream(
             self._api, self._gateway, self._house_ids, push
         )
         await self.activity_stream.async_setup()
-        push.subscribe(self.async_push_message)
+        # Use partial to bind the source parameter
+        push_callback = partial(self.async_push_message, source=push_source)
+        push.subscribe(push_callback)
         self._push_unsub = await push.run(user_data["UserID"], self.brand)
 
     async def _async_initial_sync(self) -> None:
@@ -165,17 +172,76 @@ class YaleXSData(SubscriberMixin):
                 )
 
     def async_push_message(
-        self, device_id: str, date_time: datetime, message: dict[str, Any]
+        self,
+        device_id: str,
+        date_time: datetime,
+        message: dict[str, Any],
+        source: Source | str = "unknown",
     ) -> None:
         """Process a push message."""
+        try:
+            self._async_handle_push_message(device_id, date_time, message, source)
+        except Exception:
+            _LOGGER.exception(
+                "Error processing push message for device %s at %s: %s",
+                device_id,
+                date_time,
+                message,
+            )
+            # If we have an error, we want to continue processing other messages
+            return
+
+    def _async_handle_push_message(
+        self,
+        device_id: str,
+        date_time: datetime,
+        message: dict[str, Any],
+        source: Source | str,
+    ) -> None:
+        """Handle a push message."""
+        _LOGGER.debug("async_push_message from %s: %s %s", source, device_id, message)
         device = self.get_device_detail(device_id)
-        activities = activities_from_pubnub_message(device, date_time, message)
+        activities = activities_from_pubnub_message(device, date_time, message, source)
+
+        # Check if this is a push message with unchanged state
+        changed = not self._is_unchanged_push_state(
+            device_id, message, source, activities
+        )
         activity_stream = self.activity_stream
+        _LOGGER.debug("async_push_message activities: %s for %s", activities, device_id)
         if activities and activity_stream.async_process_newer_device_activities(
             activities
         ):
+            _LOGGER.debug(
+                "async_push_message newer activities: %s for %s", device_id, activities
+            )
             self.async_signal_device_id_update(device.device_id)
-            activity_stream.async_schedule_house_id_refresh(device.house_id)
+            if not changed:
+                _LOGGER.debug(
+                    "Skipping unchanged %s state for %s: status=%s, lockAction=%s, doorState=%s",
+                    source,
+                    device_id,
+                    message.get("status"),
+                    message.get("lockAction"),
+                    message.get("doorState"),
+                )
+                return
+            for activity in activities:
+                # Don't trigger a house refresh if the activity is a status update
+                # to avoid unnecessary API calls.
+                if activity.is_status:
+                    _LOGGER.debug(
+                        "async_push_message activity: %s is status update",
+                        activity,
+                    )
+                    continue
+                _LOGGER.debug(
+                    "async_push_message activity triggering refresh: %s for %s",
+                    device_id,
+                    activity,
+                )
+                activity_stream.async_schedule_house_id_refresh(device.house_id)
+                break
 
     async def async_stop(self, *args: Any) -> None:
         """Stop the subscriptions."""
@@ -449,6 +515,50 @@ class YaleXSData(SubscriberMixin):
             )
             del self._doorbells_by_id[device_id]
 
+    def _is_unchanged_push_state(
+        self,
+        device_id: str,
+        message: dict[str, Any],
+        source: Source | str,
+        activities: list[Activity],
+    ) -> bool:
+        """Check if a push message represents unchanged state."""
+        # Build state key based on source - different sources track state separately
+        state_key = f"{device_id}:{source}"
+        # Get last known state
+        last_state = self._last_push_state.get(state_key)
+
+        # Get relevant state fields based on source
+        if source == Source.WEBSOCKET:
+            # WebSocket uses lockAction and doorState
+            if "lockAction" not in message and "doorState" not in message:
+                return False
+            current_state = {
+                "lock": message.get("lockAction", ""),
+                "door": message.get("doorState", ""),
+            }
+        else:  # PubNub
+            # PubNub uses status and doorState
+            if "status" not in message and "doorState" not in message:
+                return False
+            current_state = {
+                "lock": message.get("status", ""),
+                "door": message.get("doorState", ""),
+            }
+            # If all activities are status updates and we have a last state,
+            # check if the state is unchanged but don't update tracking
+            if last_state and all(activity.is_status for activity in activities):
+                # Status update with changed state or no previous state - don't track it
+                return last_state == current_state
+
+        # If we have a previous state and it matches current state, it's unchanged
+        if last_state and last_state == current_state:
+            return True
+
+        # Update the last known state (only for real actions, not status updates)
+        self._last_push_state[state_key] = current_state
+        return False
+
     def _remove_inoperative_locks(self) -> None:
         # Remove non-operative locks as there must
         # be a bridge (August Connect) for them to
